@@ -1,6 +1,14 @@
 #ifndef _BIOLIBC_STRING_H_
 #define _BIOLIBC_STRING_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int     bl_chrom_name_cmp(const char *n1, const char *n2);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif  // _BIOLIBC_STRING_H_
